@@ -1,5 +1,5 @@
 import time
-import json_quickbase, xml_quickbase
+from . import json_quickbase, xml_quickbase
 from typing import Union, Dict
 import os
 import getpass
@@ -25,8 +25,6 @@ def get_client(json_sdk: bool = None, creds: Dict=None) -> Union[json_quickbase.
 
     realmhost = url.split('https://')[1]
 
-    print(realmhost)
-
     if json_sdk:
         new_qb_client = json_quickbase.Client(
             realmhost=realmhost, base_url=url, user_token=user_token)
@@ -45,7 +43,6 @@ def set_qb_info():
     Function to set the default Quickbase information to initialize client objects. Writes each input into a .env file to create environmental variables.
     WARNING: The .env file is created in your CWD. If your project is shared on github, be sure to add .env to your .gitignore!
     """
-    print(os.getcwd())
     QB_URL = input('Quickbase URL (include https): ')
     QB_USER_TOKEN = input('User Token: ')
     QB_USERNAME = input('Username: ')
